@@ -441,8 +441,8 @@ use L2hos;
 use vars qw(%prefs %cfg %newcfg);
 
 # This is the central place to modify the release name and date!!!
-my $RELEASE = '2019.2';
-my $VERSION = 'Released June 5, 2019';
+my $RELEASE = '2020.2';
+my $VERSION = 'Released July 1, 2020';
 
 # --------------------------------------------------------------------------
 # Open log
@@ -606,7 +606,7 @@ if(&is_true(&get_name('TEXLIVE'))) {
 # --------------------------------------------------------------------------
 
 my $extrapath = $opt{EXTRAPATH} || $prefs{EXTRAPATH} || '';
-@paths = grep(-d, uniquify(@paths, split(/[:;]/,$extrapath)));
+@paths = grep(-d, uniquify(@paths, split(/\Q$pathd/,$extrapath)));
 #logit("DEBUG: EXTRAPATH=$extrapath\n");
 #logit("DEBUG: PATH=" . join(':',@paths) . "\n");
 
@@ -906,10 +906,11 @@ if($texpath eq 'no') {
 elsif(!$texpath && $kpath) {
   my @texpaths = ();
   chomp($kpath);
-  foreach(split(/[:;]/,$kpath)) {
+  foreach(split(/\Q$pathd/,$kpath)) {
     s/^!+//; # strip leading !'s
     s:[/\\]+$::; # strip trailing path delims
-    if(!/^[\.\w]/ && -d) {
+    $_ = L2hos->path2os($_);
+    if(L2hos->is_absolute_path($_) && -d) {
       push(@texpaths,$_);
     }
   }
@@ -1079,6 +1080,23 @@ if($opt{'IMAGES'}) {
   }
 }
 
+# --------------------------------------------------------------------------
+# ps2pdf
+# --------------------------------------------------------------------------
+
+$newcfg{'PS2PDF'} = '';
+
+if($opt{'IMAGES'}) {
+  my $ps2pdf = &find_prog(&get_name('PS2PDF',1));
+  if($ps2pdf) {
+    $newcfg{'PS2PDF'} = $ps2pdf;
+  }
+}
+
+# --------------------------------------------------------------------------
+# pdfcrop
+# --------------------------------------------------------------------------
+
 $newcfg{'PDFCROP'} = '';
 
 if($opt{'IMAGES'}) {
@@ -1214,7 +1232,7 @@ EOF
 
         # Set up the Ghostscript library path
 
-        &checking('for ghostscript library and font paths');
+        &checking('for ghostscript library path');
         my @try_path = @gs_lib_path;
 
         # Filter valid paths from environment, if set
@@ -1240,7 +1258,7 @@ EOF
             /usr/local/share/gs /usr/local/lib/gs));
         }
 
-        # Now look for "gs_init.ps" and the "fonts" directory. Also try to add
+        # Now look for "gs_init.ps". Also try to add
         # - the Ghostscript version or
         # - "gs<version>"
         # to the path. This should cover a large number of configurations.
@@ -1248,38 +1266,39 @@ EOF
         my $path;
         my @right_paths = ();
         my $gs_lib = 0;
-        my $gs_fonts = 0;
+	# 2017-04-11 shige: 2-24)
+	my $gs_stand_ps;
         Gslibpaths: foreach $path (@try_path) {
           foreach('',"$dd$gs_version","${dd}gs$gs_version") {
             my $testpath = $path . $_;
-            if(!$gs_lib && -d $testpath && -s "$testpath${dd}gs_init.ps") {
+            # if(!$gs_lib && -d $testpath && -s "$testpath${dd}gs_init.ps") {
+	    # 2017-04-11, 2019-12-03 shige: 2-24)
+	    if ($testpath =~ /tlgs/) { $gs_stand_ps = "landscap.ps"; }
+	    else { $gs_stand_ps = "gs_init.ps"; }
+            if(!$gs_lib && -d $testpath && -s "$testpath${dd}$gs_stand_ps") {
               push(@right_paths,L2hos->path2os($testpath));
               $gs_lib = 1;
             }
-            $testpath .= "${dd}fonts" unless($testpath =~ /\Q$dd\Efonts$/i);
-            if(!$gs_fonts && -d $testpath) {
-              push(@right_paths,L2hos->path2os($testpath));
-              $gs_fonts = 1;
-            }
-            last Gslibpaths if($gs_lib && $gs_fonts); # got both directories
+            last Gslibpaths if($gs_lib);
           }
         }
 
         my @additional_paths = ();
-        unless($gs_lib && $gs_fonts) {
+        unless($gs_lib) {
           &result('no');
           logit(<<"EOF");
 Warning: Could not determine GS_LIB path.
          Ghostscript may not work due to missing startup files.
          You need to set the value of GS_LIB manually in $CFGFILE.
-Hint:    Search for the file 'gs_init.ps'. This directory and the 'fonts'
-         directory (usually same level) should be set in GS_LIB.
+Hint:    Search for the file 'gs_init.ps'. 
+         This directory should be set in GS_LIB.
          Separate the entries with the "$pathd" character. The current
          directory "." should be included, too.
 EOF
         }
         else {
-           push(@right_paths,'.');
+           #push(@right_paths,'.');
+	   # 2019-12-16 shige: 2-24) 
            my $item;
            foreach $item (@right_paths) {
              $item = &simplify_path($item);
@@ -1364,9 +1383,9 @@ if($opt{'have_pstoimg'}) {
         $vers = $1;
         ($major_vers) = $vers =~ /^(\d+)/;
     }
+    &checking('if pnmcrop can crop from one direction');
     if ($major_vers =~ /^199/) {
 	# try left crop
-	&checking('if pnmcrop can crop from one direction');
         my $timg = "config${dd}timg.pnm";
 	($stat,$msg,$err) = &get_out_err("$pnmcrop -l $timg");
     } elsif ($major_vers > 8) {
@@ -1383,7 +1402,6 @@ if($opt{'have_pstoimg'}) {
 		$newcfg{'PNMCROPOPT'} = ' -sides ';
 	    }
 	} else { $newcfg{'PNMCROPOPT'} = ' -sides '; }
-	print "\n$pnmcrop";
 	$msg = 'there is nothing to crop'; $stat = '';
     } else {
 	print "\nThis $vers for $pnmcrop is not recognisable.";
@@ -1500,8 +1518,8 @@ if(1) {
     $msg = $msg || $err;
     my $vers = '';
     if ($msg =~ /(^|\s*)Version.*\s([\d\.]+)\s*([\n\r]|$)/is) { $vers = $2; }
+    &checking('if ppmtogif can make transparent GIFs');
     if ($vers =~ /^199/) {
-	&checking('if ppmtogif can make transparent GIFs');
 	# '-h' is an invalid option. Nevertheless it forces ppmtogif to output a
 	# usage information to stderr. We'll have a closer look at that.
 	($stat,$msg,$err) = &get_out_err("$ppmtogif -h");
